Important changes to repositories hosted on mbed.com
Mbed hosted mercurial repositories are deprecated and are due to be permanently deleted in July 2026.
To keep a copy of this software download the repository Zip archive or clone locally using Mercurial.
It is also possible to export all your personal repositories from the account settings page.
Dependencies: ST_INTERFACES X_NUCLEO_COMMON
Dependents: Ultrasound_And_IMU
Fork of X_NUCLEO_6180XA1 by
Diff: Components/Interfaces/RangeSensor.h
- Revision:
- 3:454541a079f4
- Parent:
- 1:1de1ea2994d9
- Child:
- 4:a5abf7757947
--- a/Components/Interfaces/RangeSensor.h Thu Sep 10 08:40:54 2015 +0000
+++ b/Components/Interfaces/RangeSensor.h Fri Sep 11 14:39:00 2015 +0200
@@ -1,11 +1,11 @@
/**
******************************************************************************
- * @file HumiditySensor.h
+ * @file RangeSensor.h
* @author AST / EST
* @version V0.0.1
* @date 13-April-2015
* @brief This file contains the abstract class describing in general
- * the interfaces of an ambient light sensor (ALS)
+ * the interfaces of a range sensor
******************************************************************************
* @attention
*
@@ -37,24 +37,24 @@
*/
/* Define to prevent from recursive inclusion --------------------------------*/
-#ifndef __LIGHT_SENSOR_CLASS_H
-#define __LIGHT_SENSOR_CLASS_H
+#ifndef __RANGE_SENSOR_CLASS_H
+#define __RANGE_SENSOR_CLASS_H
/* Includes ------------------------------------------------------------------*/
#include <GenericSensor.h>
/* Classes ------------------------------------------------------------------*/
/** An abstract class for Humidity sensors
*/
-class LightSensor : public GenericSensor
+class RangeSensor : public GenericSensor
{
public:
/**
* @brief Get current light [lux]
* @param[out] pfData Pointer to where to store light to
* @return 0 in case of success, an error code otherwise
*/
- virtual int GetLight(int *piData) = 0;
+ virtual int GetRange(int *piData) = 0;
};
-#endif /* __LIGHT_SENSOR_CLASS_H */
\ No newline at end of file
+#endif /* __RANGE_SENSOR_CLASS_H */
\ No newline at end of file
@@ -37,24 +37,24 @@
#include <GenericSensor.h>
/* Classes ------------------------------------------------------------------*/
-/** An abstract class for Humidity sensors
+/** An abstract class for range sensors
*/
@@ -37,24 +37,24 @@
public:
/**
- * @brief Get current light [lux]
- * @param[out] pfData Pointer to where to store light to
+ * @brief Get current range [mm]
+ * @param[out] piData Pointer to where to store range to
* @return 0 in case of success, an error code otherwise
*/
